/*********************************************** {COPYRIGHT-TOP} ***
* IBM Confidential
* OCO Source Materials
* 5724-V51
*
* (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
*
* The source code for this program is not published or otherwise
* divested of its trade secrets, irrespective of what has been
* deposited with the U.S. Copyright Office.
************************************************ {COPYRIGHT-END} **/



/**
 *  Copyright IBM Corp. and other(s) 2000, 2008 All Rights Reserved. 
 *
 * The following sample of source code ("Sample Code") is owned by International Business Machines Corporation or 
 * one of its subsidiaries ("IBM") and is copyrighted and licensed, not sold.
 * You may use, copy, modify, and distribute the Sample Code in any form without payment to IBM, for the purpose of assisting you in the development of your applications.

 * The Sample Code is provided to you on an "AS IS" basis, without warranty of any kind. 
 * IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * Some jurisdictions do not allow for the exclusion or limitation of implied warranties, so the above limitations or exclusions may not apply to you. 
 * IBM shall not be liable for any damages you suffer as a result of using, copying, modifying or distributing the Sample Code, even if IBM has been advised of the possibility of such damages.
 **/
package com.ibm.ccd.loader;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.Reader;

import com.ibm.ccd.loader.SimpleCSVParser;

/***
 * This class is used to load the propertirs defined in the property file
 */
public class PropertyLoader {

	//Note the properties are case sensitive
	
	public static final String PROP_CATALOG = "Catalog";
	public static final String PROP_COLLABORATION_AREA = "CollaborationArea";
	public static final String PROP_PROCESSING_OPTIONS = "DisableProcessingOptions";
	public static final String PROP_ITEM_CHECKOUT_SIZE = "ItemCheckoutSize";
	public static final String PROP_ITEM_SAVE_BATCH_SIZE = "ItemSaveBatchSize";

	//values initialised in the property file
	public class PropertyFileProperties
	{
		public String defaultCatalog;
		public String collaborationAreaName;
		public boolean disableProcessingOptions;
		public int checkoutItemSize;
		public int itemSaveBatchSize;
	}

	/***
	 * Reads the property file and initializes the default catalog name 
	 * and the collaboration Area name and the processing options,
	 * FileNotFoundException  is handled when the path of the property file is incorrect
	 * @param propertyFile  path of the property file - docstore path or Filesystem Path
	 * @return the PropertyFileProperties object
	 * @throws FileNotFoundException - When the file(data file or the property file) does not exist
	 * @throws IOException - occurs when parsing the files
	 * @throws PIMAuthorizationException - when user is not Aythorized to do the operation
	 */
	public PropertyFileProperties readPropertyFile(String propertyFile) throws FileNotFoundException,IOException,Exception
	{		  
		PropertyFileProperties properties = new PropertyFileProperties();
		Reader reader;        	
		boolean bDone = false;
		//get the Reader based on if the path corresponds to a File or a Document in the docstore            
		reader = ProcessorUtils.getReader(propertyFile);
		if(reader == null)
		{
			return null;
		}
		SimpleCSVParser parser = new SimpleCSVParser(reader);
		String[] arg;
		//skipping the header line of the property file
		parser.skipLine();
		while (!bDone)
		{
			arg = parser.splitLine();
			bDone = (arg == null);
			if(arg!=null)
			{            
				if (arg[0].equals(PROP_CATALOG))
				{
					properties.defaultCatalog = arg[1];
				}	
				if(arg[0].equals(PROP_COLLABORATION_AREA))
				{
					properties.collaborationAreaName = arg[1];
				}	
				if(arg[0].equals(PROP_PROCESSING_OPTIONS))
				{
					properties.disableProcessingOptions = Boolean.valueOf(arg[1]);
				}
				if(arg[0].equals(PROP_ITEM_CHECKOUT_SIZE))				
				{
					properties.checkoutItemSize = Integer.valueOf(arg[1]);
				}
				if(arg[0].equals(PROP_ITEM_SAVE_BATCH_SIZE))				
				{
					properties.itemSaveBatchSize = Integer.valueOf(arg[1]);
				}
			}
		}           
		return properties;

	}

}
