/*********************************************** {COPYRIGHT-TOP} ***
* IBM Confidential
* OCO Source Materials
* 5724-V51
*
* (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
*
* The source code for this program is not published or otherwise
* divested of its trade secrets, irrespective of what has been
* deposited with the U.S. Copyright Office.
************************************************ {COPYRIGHT-END} **/



/**
 *  Copyright IBM Corp. and other(s) 2000, 2008 All Rights Reserved. 
 *
 * The following sample of source code ("Sample Code") is owned by International Business Machines Corporation or 
 * one of its subsidiaries ("IBM") and is copyrighted and licensed, not sold.
 * You may use, copy, modify, and distribute the Sample Code in any form without payment to IBM, for the purpose of assisting you in the development of your applications.

 * The Sample Code is provided to you on an "AS IS" basis, without warranty of any kind. 
 * IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * Some jurisdictions do not allow for the exclusion or limitation of implied warranties, so the above limitations or exclusions may not apply to you. 
 * IBM shall not be liable for any damages you suffer as a result of using, copying, modifying or distributing the Sample Code, even if IBM has been advised of the possibility of such damages.
 **/
package com.ibm.ccd.loader;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;

/***
 * 
 * This class is used to parse a CSV formatted file.
 *
 */
public class SimpleCSVParser
{
	private BufferedReader br;
	private FileReader fr;
	private String line;
	private String split;
	private int lineLength;

	public SimpleCSVParser(String csvFile) throws IOException, FileNotFoundException
	{
		fr = new FileReader(csvFile);
		br = new BufferedReader(fr);
	}

	public SimpleCSVParser(Reader reader) throws IOException, FileNotFoundException
	{
		br = new BufferedReader(reader);
	}

	/***
	 * Splits a line using comma as the delimiter and returns the values in that line as a string array.
	 * @return a String array of values separated by comma
	 * @throws IOException
	 */
	public String[] splitLine() throws IOException
	{
		List<String> alSplits = new ArrayList<String>();
		line = getNextLine();
		if (line == null)
		{
			return null;
		}
		lineLength = line.length();
		int currentPos = 0;
		while (currentPos < lineLength)
		{
			currentPos = readNextValue(currentPos);
			alSplits.add(split);
			currentPos++;
		}
		//To handle when the last character of the line is a ','. eg: 14,124,Loader_Primary_Spec/pk,
		if(line.charAt(lineLength - 1) == ',')	
		{ 
			alSplits.add("");
		} 
		int nSplits = alSplits.size();
		String strSplits[] = new String[nSplits];
		for (int i = 0; i < nSplits; i++)
		{
			strSplits[i] = (String)alSplits.get(i);
			strSplits[i] = strSplits[i].trim();
		}
		return strSplits;
	}

	/***
	 * 
	 * @returns the nextline
	 * @throws IOException
	 */
	private String getNextLine() throws IOException
	{
		String line = br.readLine();
		return line;
	}

	/***
	 *
	 * @param currentPosition to start reading the values
	 * @return The index where comma was found
	 */
	private int readNextValue(int p)
	{
		char c;
		split = "";
		c = readChar(p);
		if (c != '"')
		{
			int nextCommaIndex = line.indexOf(',', p);
			if (nextCommaIndex == -1)
			{
				nextCommaIndex = lineLength;
			}
			split = line.substring(p, nextCommaIndex);
			return nextCommaIndex;
		}
		p++;
		while (true)
		{
			c = readChar(p);
			p++;
			if (c == '"')
			{
				if (p == lineLength)
				{
					return p;
				}
				c = readChar(p);
				p++;
				if (c == '"')
				{
					split += c;
					continue;
				}
				if (c == ',')
				{
					return p - 1;
				}				
			}
			split += c;			
		}
	}

	/***
	 * This method is used to skip a line from the file. Used to skip the header line
	 * @throws IOException
	 */
	public void skipLine() throws IOException
	{
		line = getNextLine();
	}

	/***
	 * 
	 * @param index of the character
	 * @return the character at the index
	 */
	private char readChar(int p)
	{
		return line.charAt(p);
	}

}

