/*********************************************** {COPYRIGHT-TOP} ***
* IBM Confidential
* OCO Source Materials
* 5724-V51
*
* (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
*
* The source code for this program is not published or otherwise
* divested of its trade secrets, irrespective of what has been
* deposited with the U.S. Copyright Office.
************************************************ {COPYRIGHT-END} **/




/*
* Licensed Materials: Property of IBM
* "Restricted Materials of IBM"
* 5724-I68.
* (C) Copyright IBM Corp. 2000, 2005 - All Rights Reserved.
* US Government Users Restricted Rights - Use, duplication or disclosure
* restricted by GSA ADP Schedule Contract with IBM Corp.
*/


package com.ibm.ccd.ui.taglib.dataobjects;

import java.util.HashMap;

import com.ibm.ccd.ui.tags.ISelectListTag;
import com.ibm.ccd.ui.util.ValidationUtil;
import com.ibm.ccd.ui.dataobjects.NVPair;
import com.ibm.ccd.ui.dataobjects.attributes.Attribute;

/**
* Base class for all SearchElements
* @author  IBM India
* @version 1.0
* @since   Iteration 2
**/
public class BaseSearchElement implements ISeachElement, ISelectListTag,
    Cloneable {
    /**
     * literal for suffix to recongnize the Searchoperator related to the searchElement
     */
    private static final String operator_SUFFIX = "_OP";

    /**
     * Element Type viz: Text/Select/Lookup
     **/
    private int elementType;
    
    private int wpcAttributeType;

    /**
     * Whether the  Element is essentail for performing search
     * true: essential <br>
     * false :  not necessary
     **/
    private boolean isMandatoryElement;

    /**
     * Element Name
     **/
    private String elementName;

    /**
     * Element ID, represented in the browser , should be unique
     **/
    private String elementID;

    /**
     * Operator ID, should be unique
     **/
    private String operatorID;

    /**
     * List of available operators
     **/
    private HashMap operatorsMap;

    /**
     * Default Operator for performing search against this element
     **/
    private String defaultOperator;

    /**
     * Selected operator for performing search against this Element
     **/
    private Integer selectedOperator;

    /**
     * Specifies the visibility of the element
     */
    private boolean isDisplayable;

    /**
     * Specifies the sortability of the element
     */
    private boolean isSortable;

    /**
     * Specifies whether the search is defaultable
     */
    private boolean isDefaultable;
    private String selectedValue = null;
    private String displayName = null;
    private int listBoxIndex = -1;

    /**
     * Used for reange bound search element
     */
    private BaseSearchElement childElement = null;
    
	private Attribute wpcAttribute=null;
	
	private boolean searchable=false;

    /**
    * Constructs an empty SearchElement
    **/
    public BaseSearchElement() {
    }

    /**
     * Constructs SearchElement with the specified type
     * @param aElementType - The type of the element as defined in the ISearchElementTypesEnum
     **/
    public BaseSearchElement(int aElementType) {
        this.elementType = aElementType;
    }

    /**
     * Constructs SearchElement for  the specified type, display and sort capabilities
     * @param aElementName - The Name of the element
     * @param aDisplayable - Displayability of the element in the UI
     * @param aSortable  - The sortability of the element
     **/
    public BaseSearchElement(String aElementName, boolean aDisplayable,
        boolean aSortable) {
        this.elementName = aElementName;
        this.isDisplayable = aDisplayable;
        this.isSortable = aSortable;
    }

    /**
             * Constructs SearchElement for the specified type, name, displayable and sortable capabilities
             * @param aElementType - The type of the element
             * @param aElementName
             * @param aDisplayable - Displayability of the element in the UI
             * @param aSortable  - The sortability of the element
            
             **/
    public BaseSearchElement(int aElementType, String aElementName,
        boolean aDisplayable, boolean aSortable) {
        this.elementName = aElementName;
        this.elementType = aElementType;
        this.isDisplayable = aDisplayable;
        this.isSortable = aSortable;
    }

    /**
             * Constructs SearchElement for the specified type, name, displayable and sortable capabilities
             * @param aElementType - The type of the element
             * @param aElementName - The name of the element
         * @param aDefaultOperator - The default searchOperator
             * @param aOperatorsMap - The operator hashMap
             * @param aMandatory - The essentiality of the element
             * @param aDefaultable - The default value presence of the element
             **/
    public BaseSearchElement(int aElementType, String aElementName,
        String aDefaultOperator, HashMap aOperatorsMap, boolean aMandatory,
        boolean aDefaultable) {
        this(aElementType, aElementName, aElementName, aDefaultOperator,
            aOperatorsMap, aMandatory, aDefaultable);
    }

    /**
             * Constructs SearchElement for the specified type, name, displayable and sortable capabilities
             * @param aElementType - The type of the element
             * @param aElementID - The Id of the searchElement
             * @param aElementName - The name of the element
             * @param aDefaultOperator - The default searchOperator
             * @param aOperatorsMap - The operator hashMap
             * @param aIsMandatory - The essentiality of the element
             * @param aIsDefaultable - The default value presence of the element
             **/
    public BaseSearchElement(int aElementType, String aElementName,
        String aElementID, String aDefaultOperator, HashMap aOperatorsMap,
        boolean aIsMandatory, boolean aIsDefaultable) {
        this.elementType = aElementType;
        this.elementName = aElementName;
        this.elementID = aElementID;
        this.defaultOperator = aDefaultOperator;
        this.operatorsMap = aOperatorsMap;
        this.isMandatoryElement = aIsMandatory;
        this.isDefaultable = aIsDefaultable;

        // SearchOperatorID 
        this.operatorID = elementID + operator_SUFFIX;
    }

    /**
     * Retrurns the Unique ID to identify this element
     * @return The Element Identifier
     **/
    public String getID() {
        return (elementID != null) ? elementID : elementName;
    }

    /**
    * Retrurns the name of this element
    * @return String, The Element Name
    **/
    public String getName() {
        return elementName;
    }

    /**
     * Retrurns the element Type
     * @return The Element Type, int
     **/
    public int getType() {
        return elementType;
    }

    /**
     * Retrurns the Default operator for this element
     * @return The Default Operator associated. Integer
     **/
    public String getDefaultOperator() {
        return defaultOperator;
    }

    /**
     *Returns the Unique ID identify this elements operator
     * @return The Element Operator Identifier
     **/
    public String getOperatorID() {
        return operatorID;
    }

    /**
     * Sets the unique ID identify this element operator
     * @param aOperatorID The Element Operator Identifier
     **/
    public void setOperatorID(String aOperatorID) {
        this.operatorID = aOperatorID;
    }

    /**
    * Returns the allowed operators map , associated with this element
    * @return The allowed Element Operator Map
    **/
    public HashMap getOperatorsMap() {
        return operatorsMap;
    }

    /**
     * Returns the Current Operator selected fot this element
     * @return Selected Operator , if assigned and not null <br>
     *         else the default Operator
     **/
    public Integer getSelectedOperator() {
        return selectedOperator;
    }

    /**
     * Specifies whether this operator is mandatory or not
     * @return true, if this operator is mandatory
     *         else false, if this is not mandatory
     **/
    public boolean isMandatory() {
        return isMandatoryElement;
    }

    /**
     * Sets the ID  of this element
     * @param  aElementID , The element unique ID
     **/
    public void setID(String aElementID) {
        this.elementID = aElementID;
    }

    /**
     * Sets the name  of this element
     * @param  aElementName , Name of this  element<br>
     **/
    public void setName(String aElementName) {
        this.elementName = aElementName;
    }

    /**
     * Sets the type of this element
     * @param  aElementType , The element type
     **/
    public void setType(int aElementType) {
        this.elementType = aElementType;
    }

    /**
     * Sets the default  of this element for perfroming search
     * @param  aDefaultOperator , If  the element is mandatory <br>
     **/
    public void setDefaultOperatorID(String aDefaultOperator) {
        this.defaultOperator = aDefaultOperator;
    }

    /**
     * Sets the requirement of this element for perfroming search
     * @param aIsMandatoryElement true , If  the element is mandatory <br>
     *         false , If the element is not mandatory
     **/
    public void setMandatory(boolean aIsMandatoryElement) {
        this.isMandatoryElement = aIsMandatoryElement;
        if(aIsMandatoryElement){
        	this.isDisplayable=true;
        }
    }

    /**
     * Assigns the list of available operators  for perfroming search against this element
     * @param aOperatorsMap , the map of allowed operators ( key as operator name eg. ">" value is the oerparotorvalue eg" 1" )
     **/
    public void setOperatorMap(HashMap aOperatorsMap) {
        this.operatorsMap = aOperatorsMap;
    }

    /**
     * Assigns the selected operator for perfroming search against this element
     * @param aSelectedOperator , the selected operator from the list of available operators.
     **/
    public void setSelectedOperator(Integer aSelectedOperator) {
        this.selectedOperator = aSelectedOperator;
    }

    /**
     *  Assigns the selected operator for perfroming search against this element
     *  this is the convenient overloaded method , used to fill using the string values from the browser
     * @param aSelectedOperatorStr , the selected operaor from the list of available operators.
    
     **/
    public void setSelectedOperator(String aSelectedOperatorStr) {
        try {
            this.selectedOperator = new Integer(aSelectedOperatorStr);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Gets the isDisplayable
     * @return Returns a boolean
     */
    public boolean getIsDisplayable() {
        return isDisplayable;
    }

    /**
     * Sets the isDisplayable
     * @param isDisplayable The isDisplayable to set
     */
    public void setIsDisplayable(boolean isDisplayable) {
        this.isDisplayable = isDisplayable;
    }

    /**
     * Gets the isSortable
     * @return Returns a boolean
     */
    public boolean getIsSortable() {
        return isSortable;
    }

    /**
     * Sets the isSortable
     * @param isSortable The isSortable to set
     */
    public void setIsSortable(boolean isSortable) {
        this.isSortable = isSortable;
    }

    /**
     * Gets the isDefaultable
     * @return Returns a boolean
     */
    public boolean isDefaultable() {
        return isDefaultable;
    }

    /**
     * Sets the isDefaultable
     * @param aDefaultable The isDefaultable to set
     */
    public void setDefaultable(boolean aDefaultable) {
        this.isDefaultable = aDefaultable;
    }

    /**
     * @return string
     */
    public String getSelectedValue() {
        return selectedValue;
    }

    public String getSelectedDisplayValue() {
        String value = null;
        SelectSearchElement element = null;
        NVPair[] possibleValues = null;

        if (this.elementType == ISearchElementTypesEnum.SELECT) {
            element = (SelectSearchElement) this;
            possibleValues = element.getPossibleValues();
            for (int i=0;i<possibleValues.length;i++){
            	if(element.getSelectedValue().equals(possibleValues[i].getName())){
					value=possibleValues[i].getValue().toString();            		
            		break;
            	}
            }
        } else {
            value = this.selectedValue;
        }

        return value;
    }

    /**
     * @param string
     */
    public void setSelectedValue(String string) {
        selectedValue = string;
    }

    /**
     * @return string
     */
    public String getDisplayName() {
	
        return displayName;
    }

    /**
     * @param string
     */
    public void setDisplayName(String string) {
        displayName = string;
    }

    /**
     * @return baseSearchElement
     */
    public BaseSearchElement getChildElement() {
        return childElement;
    }

    /**
     * @param element
     */
    public void setChildElement(BaseSearchElement element) {
        childElement = element;
    }

    public Object clone() throws CloneNotSupportedException {
        BaseSearchElement element = null;
        element = (BaseSearchElement) super.clone();
        element.operatorsMap = (HashMap) operatorsMap.clone();
        return element;
    }

    public boolean isSelected() {
        boolean isSelected = false;
        isSelected = getIsDisplayable();

        return isSelected;
    }

    /**
     * @return integer
     */
    public int getListBoxIndex() {
        return listBoxIndex;
    }

    /**
     * @param i
     */
    public void setListBoxIndex(int i) {
        listBoxIndex = i;
    }

    /**
     * @return integer
     */
    public int getWpcAttributeType() {
        return wpcAttributeType;
    }

    /**
     * @param i
     */
    public void setWpcAttributeType(int i) {
        wpcAttributeType = i;
    }
	/**
	 * @return attribute
	 */
	public Attribute getWpcAttribute() {
		return wpcAttribute;
	}

	/**
	 * @param attribute
	 */
	public void setWpcAttribute(Attribute attribute) {
		wpcAttribute = attribute;
	}
	
	public void setSearchable(boolean flag){
		searchable=flag;
	}
	
	public boolean isSearchable(){
		return searchable;
	}

}
