/*********************************************** {COPYRIGHT-TOP} ***
* IBM Confidential
* OCO Source Materials
* 5724-V51
*
* (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
*
* The source code for this program is not published or otherwise
* divested of its trade secrets, irrespective of what has been
* deposited with the U.S. Copyright Office.
************************************************ {COPYRIGHT-END} **/




/*
* Licensed Materials: Property of IBM
* "Restricted Materials of IBM"
* 5724-I68.
* (C) Copyright IBM Corp. 2000, 2005 - All Rights Reserved.
* US Government Users Restricted Rights - Use, duplication or disclosure
* restricted by GSA ADP Schedule Contract with IBM Corp.
*/


package com.ibm.ccd.ui.taglib.dataobjects;

import java.util.ArrayList;


/**
*Represents the Results of an action like Search, Lookup
*          This class provides the detail information about the  results  data like <br>
*          MetaData    : The result elements name, type etc. <br>
*          ControlData : Start,End indexes, Current and TotalSize of the results <br>
*          ResultData  :  The current result set associated
* @author  IBMIndia
* @version 1.0
**/
public class ResultData {
   /**
    *  Total result size associated with the the current search
    */
    private long totalResultSize;

  
    /**
    *  MetaData associated with the the current search
    **/
    private ArrayList resultMetaData;

    /**
    *   Result rows and data associated with the the current search
    **/
    private ArrayList resultRowData;

    /**
    * Constructs an empty ResutlData
    **/
    public ResultData() {
        this.resultMetaData = new ArrayList(5);
        this.resultRowData = new ArrayList(5);
    }

    /**
    * Constructs  ResutlData with the specified metadata and resultrows
    * @param aResultMetaData
    * @param aResultRowData
    **/
    public ResultData(ArrayList aResultMetaData, ArrayList aResultRowData) {
        this.resultMetaData = aResultMetaData;
        this.resultRowData = aResultRowData;
    }

    /**
    *Returns the MetaData associated with the current results
    * @return ArrayList of Metadata elements
    **/
    public ArrayList getResultMetaData() {
        return resultMetaData;
    }

    /**
    * Returns the MetaData associated with the current results
    * @param index
    * @return ArrayList of Metadata elements
    **/
    public ResultMetaData getResultMetaData(int index) {
        return ((resultMetaData != null) && (resultMetaData.size() > 0))
        ? (ResultMetaData) resultMetaData.get(index) : null;
    }

    /**
     *Returns the ResultData associated with the current results
    * @return ArrayList , Array of Result Rows
    **/
    public ArrayList getResultRowData() {
        return resultRowData;
    }

    /**
    * Returns the ResultRow at the specidied index
    * @param index of the ResultRows
    * @return ResultRowData at the given index
    **/
    public ResultRowData getResultRowData(int index) {
        return ((resultRowData != null) && (resultRowData.size() > 0))
        ? (ResultRowData) resultRowData.get(index) : null;
    }

    /**
     * Sets the metadata  for the current  results
     * @param  aResultMetaData of MetadataElements
     **/
    public void setResultMetaData(ArrayList aResultMetaData) {
        this.resultMetaData = aResultMetaData;
    }

   
    /**
     * Sets the resultdata  for the current results
     * @param aResultRowData of Search Result Row Elements
     **/
    public void setResultRowData(ArrayList aResultRowData) {
        this.resultRowData = aResultRowData;
    }


    /**
    * Returns the total result size  associated with the current results
    * @return int, Total result set size
    **/
    public long getTotalResultSize() {
        return totalResultSize;
    }


    /**
     * Sets the total size of the  current search.
     * @param totalResutltSize , total result size
     **/
    public void setTotalResultSize(long totalResutltSize) {
        this.totalResultSize = totalResutltSize;
    }

}
