/*********************************************** {COPYRIGHT-TOP} ***
* IBM Confidential
* OCO Source Materials
* 5724-V51
*
* (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
*
* The source code for this program is not published or otherwise
* divested of its trade secrets, irrespective of what has been
* deposited with the U.S. Copyright Office.
************************************************ {COPYRIGHT-END} **/




/*
* Licensed Materials: Property of IBM
* "Restricted Materials of IBM"
* 5724-I68.
* (C) Copyright IBM Corp. 2000, 2005 - All Rights Reserved.
* US Government Users Restricted Rights - Use, duplication or disclosure
* restricted by GSA ADP Schedule Contract with IBM Corp.
*/


package com.ibm.ccd.ui.taglib.dataobjects;

import com.ibm.ccd.ui.tags.ISelectListTag;


/**
* Represents the Metdadata associated with the  Results
*          This class provides the information about  result attributes <br>
*           viz. name,  type, visibility, sortable
*           This information represents the column data in the result set
* @author  IBMIndia
* @version 1.0
**/
public class ResultMetaData implements ISelectListTag {
    /**
     * Name of the result element
     **/
    private String name;
    private int type = 1;
    private int listBoxIndex = -1;
    private String displayName=null;

    /**
     * Sortability of the result element
     **/
    private boolean sortable;

    /**
     * The currently sorted property of this element
     */
    private boolean currentlySorted;

    /**
     * Visibility of the result element
     **/
    private boolean displayable = false;

    /**
     * TRUE if attribute is primary key
     */
    private boolean isMandatory = false;

    /**
     * Constructs an empty ResultMetaData
     **/
    public ResultMetaData() {
    }

    /**
     * Constructs  ResultMetaData with the specified name and sortable flag
     * @param name , Name of the ELement
     * @param type of the elemement
     *
     */
    public ResultMetaData(String name, int type) {
        this.name = name;
        this.type = type;
    }

    /**
     * Constructs  ResultMetaData with the specified name and sortable flag
     * @param name , Name of the ELement
     * @param type  type of the elemement
     * @param sortable
     * @param displayable
     */
    public ResultMetaData(String name, int type, boolean sortable,
        boolean displayable) {
        this.name = name;
        this.type = type;
        this.sortable = sortable;
        this.displayable = displayable;
    }

    /**
     * Returns the name  associated with the current  element
     * @return String, the name  of the result set element
     */
    public String getName() {
        return name;
    }

    /**
     * Returns the type of the result element
     * @return int, Element Type
     * @see    ISearchElementTypesEnum
     */
    public int getType() {
        return type;
    }

    /**
     * Sets the type of the result element
     * @param aType , Element Type
     */
    public void setType(int aType) {
        this.type = aType;
    }

    /**
     * Specifies visibility of this element
     * @return true, If the element can be displayed <br>
     *         false, If the element can not be displayed <br>
     */
    public boolean isDisplayable() {
        return displayable;
    }

    /**
     * Specifies sortability of the result set based on this element
     * @return true, If the result set can be sorted based on this  <br>
     *         false, If the result set cann't be sorted based on this  <br>
     */
    public boolean isSortable() {
        return sortable;
    }

    /**
     * Returns the action to be done to select the result Object
     * @return String, the Select action
     */

    //public String getActionForElements() {
    //return actionForColumnElements;
    //}

    /**
     *Specifies visibility of this element
     * @param aDisplayable true, If the element can be displayed <br>
     *         false, If the element can not be displayed <br>
     */
    public void setDisplayable(boolean aDisplayable) {
        this.displayable = aDisplayable;
    }

    /**
     *Sets the name  associated with the current  element
     * @param aName , the name  of the result set element
     */
    public void setName(String aName) {
        this.name = aName;
    }

    /**
     * Specifies sortability of the result set based on this element
     * @param sortable true, If the result set can be sorted based on this  <br>
     *         false, If the result set cann't be sorted based on this  <br>
     */
    public void setSortable(boolean sortable) {
        this.sortable = sortable;
    }

    /**
     * Gets the currentlySorted
     * @return Returns a boolean
     */
    public boolean getCurrentlySorted() {
        return currentlySorted;
    }

    /**
     * Sets the currentlySorted
     * @param currentlySorted The currentlySorted to set
     */
    public void setCurrentlySorted(boolean currentlySorted) {
        this.currentlySorted = currentlySorted;
    }

    public boolean isSelected() {
        return isDisplayable();
    }

    public String getDisplayName() {
       return displayName;
    }

    public int getListBoxIndex() {
        return listBoxIndex;
    }

    /**
     * @param i
     */
    public void setListBoxIndex(int i) {
        listBoxIndex = i;
    }

    /**
     * @return boolean
     */
    public boolean isMandatory() {
        return isMandatory;
    }

    /**
     * @param b
     */
    public void setMandatory(boolean b) {
        isMandatory = b;
    }
	/**
	 * @param string
	 */
	public void setDisplayName(String string) {
		displayName = string;
	}

}
